Page 101 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 101

Home

    but

    from

    by

    government.

    With this understanding it is easier to see why
    wealthy American capitalists, who wish to avoid
    competition by owning government protected
    monopolies, support revolutionary leaders who are
    socialists. Monopolistic capitalism is only made possible
    by a partnership with, or control over government.
    Monopolies are impossible without government
    protection.

    by

    What

    iS

    known

    has

    been

    as

    government protected monopolies on the other. Thus,
    while the Soviet Government was taking away the
    private property of its citizens and forcing them to work
    in collectives, such as farms, factories etc., it was also in
    partnership with, and protecting the business monopolies
    of wealthy American businessmen who helped to finance
    the revolution.

    The system that benefits the greatest number of
    people is a competitive free-enterprise system. A good
    way to illustrate this is to explode the socialist myth that,
    under free-enterprise, employers exploit their workers.

    On July 10, 1905, a speech was given at Union
    Temple Hall in Minneapolis by socialist Daniel De Leon.
    The speech "Socialist Reconstruction of Society" was
    later printed in the tens of millions of copies in principal
    languages around the world. According to Dr. Howard E.
    Kershner in his book Dividing The Wealth: Are You

    96

    The Secret Side of History

    controlled

    protected

    competition

    protected

    are impossible

    without government

    Communism

    characterized by forced collectivism on one hand and